@@ -75,17 +75,31 @@ void fill_user_stations_list_from_clock(GtkListStore** list){
 		*station_code = NULL,
 		buffer[1024];
     GtkTreeIter	iter;
+
+
+#ifndef RELEASE
+    fprintf(stderr,"BEGIN %s(): \n", __PRETTY_FUNCTION__);
+#endif
         
     GConfClient *gconf_client = gconf_client_get_default();
     /* City name from config file of clock */
     home_city = gconf_client_get_string(gconf_client,
         			    GCONF_KEY_CLOCK_HOME_LOCATION, NULL);
+
     if(!home_city)
 	return;
     remote_city = gconf_client_get_string(gconf_client,
         			    GCONF_KEY_CLOCK_REMOTE_LOCATION, NULL);
+				    
     if(!remote_city)
 	return;
+
+    /* This is code for the first start during installation of deb packet */
+    if ((clock_file = fopen(CLOCK_FILE, "r")) == NULL)
+	sleep (25);
+    else
+	fclose(clock_file);
+
     if((clock_file = fopen(CLOCK_FILE, "r"))){
 	while(!feof(clock_file)){
 	    memset(buffer, 0, sizeof(buffer));
@@ -284,6 +298,7 @@ int new_read_config(AppletConfig *config){
     /* Get GPS station name and id */
 #ifdef HILDON
     app->gps_station.name[0] = 0;
+    tmp = NULL;
     tmp = gconf_client_get_string(gconf_client,
         			    GCONF_KEY_GPS_STATION_NAME, NULL);
     if(tmp){
@@ -368,15 +383,16 @@ int new_read_config(AppletConfig *config){
         config->gps_station = FALSE;
 #endif
 
-    /* Get Weather font color. */    	
+    /* Get Weather font color. */
+    tmp = NULL;
     tmp = gconf_client_get_string(gconf_client,
         			    GCONF_KEY_WEATHER_FONT_COLOR, NULL);
     if(!tmp || !gdk_color_parse(tmp, &(config->font_color)))
          config->font_color = DEFAULT_FONT_COLOR; 
     g_free(tmp);
-    tmp = NULL;
-
+    
     /* Get background color. */    	
+    tmp = NULL;
     tmp = gconf_client_get_string(gconf_client,
         			    GCONF_KEY_WEATHER_BACKGROUND_COLOR, NULL);
     if(!tmp || !gdk_color_parse(tmp, &(config->background_color)))
@@ -409,8 +425,7 @@ int new_read_config(AppletConfig *config){
     }
     else
         config->downloading_after_connecting = FALSE;
-
-    
+	
     /* Get Swap Temperature Button State. Default is FALSE */
     value = gconf_client_get(gconf_client, GCONF_KEY_SWAP_TEMPERATURE, NULL);
     if(value){
@@ -462,7 +477,8 @@ int new_read_config(AppletConfig *config){
     if(gerror || config->days_to_show <= 0
 	      || config->days_to_show > Max_count_weather_day){
 	config->days_to_show = 5;
-	g_error_free(gerror);
+	if(gerror)
+	    g_error_free(gerror);
     }
     config->previos_days_to_show = config->days_to_show;
 
@@ -472,7 +488,8 @@ int new_read_config(AppletConfig *config){
 						    &gerror);
     if(gerror || config->distance_units > SEA_MILES){
 	config->distance_units = METERS;
-	g_error_free(gerror);
+	if(gerror)
+	    g_error_free(gerror);
     }
 
     /* Get wind units */
@@ -481,7 +498,8 @@ int new_read_config(AppletConfig *config){
 						&gerror);
     if(gerror || config->wind_units > MILES_H){
 	config->wind_units = METERS_S;
-	g_error_free(gerror);
+	if(gerror)
+	    g_error_free(gerror);
     }
     /* Get switch time */
     config->switch_time = gconf_client_get_int(gconf_client,
@@ -495,7 +513,8 @@ int new_read_config(AppletConfig *config){
 		    config->switch_time != 50 &&
 		    config->switch_time != 60) ){
 	config->switch_time = 0;	/* Default value - Never */
-	g_error_free(gerror);
+	if (gerror)
+	    g_error_free(gerror);
     }
     else{
 	if(config->switch_time > 0){
@@ -505,6 +524,7 @@ int new_read_config(AppletConfig *config){
                         	app->main_window);
 	}
     }
+    
     /* Get valid data time for current weather */
     config->data_valid_interval =
 	    gconf_client_get_int(gconf_client,
@@ -515,16 +535,18 @@ int new_read_config(AppletConfig *config){
 		    config->data_valid_interval != 4 &&
 		    config->data_valid_interval != 8) ){
 	config->data_valid_interval = 2 * 3600; /* Default value - 2 hours */
-	g_error_free(gerror);
+	if (gerror)
+	    g_error_free(gerror);
     }
     else
 	config->data_valid_interval *= 3600;
 
     /* If this first start then fill default station from clock config */ 
+    tmp = NULL;
     tmp = gconf_client_get_string(gconf_client,
-                		    GCONF_KEY_WEATHER_PROGRAM_VERSION, NULL);
+                		    GCONF_KEY_WEATHER_PROGRAM_VERSION, NULL);				    
     if(!tmp){
-	if(!app->config->current_station_id){
+	if(!app->config->current_station_id){	
 	    fill_user_stations_list_from_clock(&app->user_stations_list);
 	    if(app->iap_connected){
 		app->show_update_window = TRUE;
