@@ -663,8 +663,10 @@ void weather_buttons_fill(gboolean check_error){
 	if(!app->config->transparency && app->parent)
 	    gtk_widget_modify_bg(app->parent, GTK_STATE_NORMAL, &app->config->background_color);
     #endif 
-    if(error_station_code)
+    if(error_station_code){
 	station_error_window();
+	weather_window_settings(NULL, NULL, NULL);
+    }
 #ifndef RELEASE
     fprintf(stderr,"END %s(): \n", __PRETTY_FUNCTION__);
 #endif
